@@ -4,10 +4,9 @@ use strict;
 
 use Rose::HTML::Object::Errors qw(:number);
 
-use Rose::HTML::Form::Field::Text;
-our @ISA = qw(Rose::HTML::Form::Field::Text);
+use base 'Rose::HTML::Form::Field::Text';
 
-our $VERSION = '0.552';
+our $VERSION = '0.606';
 
 use Rose::Object::MakeMethods::Generic
 (
@@ -122,6 +121,8 @@ if(__PACKAGE__->localizer->auto_load_messages)
   __PACKAGE__->localizer->load_all_messages;
 }
 
+use utf8; # The __DATA__ section contains UTF-8 text
+
 1;
 
 __DATA__
